// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

#ifndef ICE_SSL_ICE_SSL_H
#define ICE_SSL_ICE_SSL_H

#include <IceUtil/Config.h>
#ifndef ICE_OS_WINRT
#   include <IceSSL/Plugin.h>
#endif
#include <IceSSL/EndpointInfo.h>
#include <IceSSL/ConnectionInfo.h>

#endif
